@@ -15,6 +15,8 @@
 #' 'leg_title_cex',
 #' 'leg_val_cex',
 #' 'leg_val_rnd',
+#' 'leg_val_dec',
+#' 'leg_val_big',
 #' 'leg_frame',
 #' 'breaks',
 #' 'nbreaks',
@@ -55,6 +57,8 @@ mf_grad <- function(x,
                     leg_title_cex = .8,
                     leg_val_cex = .6,
                     leg_val_rnd = 2,
+                    leg_val_dec = ".",
+                    leg_val_big = "",
                     leg_frame = FALSE,
                     leg_adj = c(0, 0),
                     leg_size = 1,
@@ -124,6 +128,8 @@ mf_grad <- function(x,
       title_cex = leg_title_cex,
       val_cex = leg_val_cex,
       val_rnd = leg_val_rnd,
+      val_dec = leg_val_dec,
+      val_big = leg_val_big,
       lwd = lwd,
       col = col,
       bg = leg_bg,
