@@ -20,8 +20,9 @@
 #'        lwd_max, val_order, pch, cex, border, lwd, col_na, cex_na, pch_na,
 #'        expandBB, add,
 #'        leg_pos, leg_title, leg_title_cex, leg_val_cex, leg_val_rnd,
-#'        leg_no_data, leg_frame, leg_frame_border, leg_horiz, leg_adj, leg_bg,
-#'        leg_fg, leg_size, leg_border, leg_box_border, leg_box_cex, ...)
+#'        leg_val_dec, leg_val_big, leg_no_data, leg_frame, leg_frame_border,
+#'        leg_horiz, leg_adj, leg_bg, leg_fg, leg_size, leg_border,
+#'        leg_box_border, leg_box_cex, ...)
 #'
 #'
 #'
@@ -38,13 +39,15 @@
 #' \preformatted{
 #' mf_map(x, var, type = "prop", inches = 0.3, val_max, symbol = "circle",
 #'        col = "tomato4", alpha = NULL, lwd_max = 20,
-#'        border = getOption("mapsf.fg"), lwd = 0.7, expandBB, add = TRUE,
+#'        border = getOption("mapsf.foreground"), lwd = 0.7, expandBB,
+#'        add = TRUE,
 #'        leg_pos = mf_get_leg_pos(x), leg_title = var,
 #'        leg_title_cex = 0.8, leg_val_cex = 0.6, leg_val_rnd = 0,
-#'        leg_frame = FALSE, leg_frame_border = getOption("mapsf.fg"),
+#'        leg_val_dec = ".", leg_val_big = "",
+#'        leg_frame = FALSE, leg_frame_border = getOption("mapsf.foreground"),
 #'        leg_horiz = FALSE, leg_adj = c(0, 0),
-#'        leg_bg = getOption("mapsf.bg"), leg_fg = getOption("mapsf.fg"),
-#'        leg_size = 1)
+#'        leg_bg = getOption("mapsf.background"),
+#'        leg_fg = getOption("mapsf.foreground"), leg_size = 1)
 #'        }
 #'
 #' **choro**: areas are shaded according to the variation of a quantitative
@@ -55,54 +58,57 @@
 #' \preformatted{
 #' mf_map(x, var, type = "choro", breaks = "quantile", nbreaks, pal = "Mint",
 #'        alpha = NULL, rev = FALSE, pch = 21, cex = 1,
-#'        border = getOption("mapsf.fg"), lwd = 0.7, col_na = "white",
+#'        border = getOption("mapsf.foreground"), lwd = 0.7, col_na = "white",
 #'        cex_na = 1, pch_na = 4, expandBB, add = FALSE,
 #'        leg_pos = mf_get_leg_pos(x), leg_title = var, leg_title_cex = 0.8,
-#'        leg_val_cex = 0.6, leg_val_rnd = 2, leg_no_data = "No data",
-#'        leg_frame = FALSE, leg_frame_border = getOption("mapsf.fg"),
-#'        leg_horiz = FALSE, leg_adj = c(0, 0), leg_bg = getOption("mapsf.bg"),
-#'        leg_fg = getOption("mapsf.fg"), leg_size = 1,
-#'        leg_box_border = getOption("mapsf.fg"), leg_box_cex = c(1, 1))
+#'        leg_val_cex = 0.6, leg_val_rnd = 2, leg_val_dec = ".",
+#'        leg_val_big = "", leg_no_data = "No data", leg_frame = FALSE,
+#'        leg_frame_border = getOption("mapsf.foreground"), leg_horiz = FALSE,
+#'        leg_adj = c(0, 0), leg_bg = getOption("mapsf.background"),
+#'        leg_fg = getOption("mapsf.foreground"), leg_size = 1,
+#'        leg_box_border = getOption("mapsf.foreground"), leg_box_cex = c(1, 1))
 #'        }
 #'
 #' **typo**: displays a typology map of a qualitative variable.
 #' `val_order` is used to set modalities order in the legend.
 #' \preformatted{
 #' mf_map(x, var, type = "typo", pal = "Dynamic", alpha = NULL, rev = FALSE,
-#'        val_order,border = getOption("mapsf.fg"), pch = 21, cex = 2,
+#'        val_order,border = getOption("mapsf.foreground"), pch = 21, cex = 2,
 #'        lwd = 0.7, cex_na = 1, pch_na = 4, col_na = "white",
 #'        leg_pos = mf_get_leg_pos(x), leg_title = var, leg_title_cex = 0.8,
 #'        leg_val_cex = 0.6, leg_no_data = "No data", leg_frame = FALSE,
-#'        leg_frame_border = getOption("mapsf.fg"), leg_adj = c(0, 0),
-#'        leg_size = 1, leg_box_border = getOption("mapsf.fg"),
-#'        leg_box_cex = c(1, 1), leg_fg = getOption("mapsf.fg"),
-#'        leg_bg = getOption("mapsf.bg"), add = FALSE)
+#'        leg_frame_border = getOption("mapsf.foreground"), leg_adj = c(0, 0),
+#'        leg_size = 1, leg_box_border = getOption("mapsf.foreground"),
+#'        leg_box_cex = c(1, 1), leg_fg = getOption("mapsf.foreground"),
+#'        leg_bg = getOption("mapsf.background"), add = FALSE)
 #'        }
 #'
 #' **symb**: displays the different modalities of a qualitative variable as
 #' symbols.
 #' \preformatted{
 #' mf_map(x, var, type = "symb", pal = "Dynamic", alpha = NULL, rev = FALSE,
-#'        border = getOption("mapsf.fg"), pch, cex = 2, lwd = 0.7,
+#'        border = getOption("mapsf.foreground"), pch, cex = 2, lwd = 0.7,
 #'        col_na = "grey", pch_na = 4, cex_na = 1, val_order,
 #'        leg_pos = mf_get_leg_pos(x), leg_title = var, leg_title_cex = 0.8,
-#'        leg_val_cex = 0.6, leg_val_rnd = 2, leg_no_data = "No data",
-#'        leg_frame = FALSE, leg_frame_border = getOption("mapsf.fg"),
-#'        leg_adj = c(0, 0), leg_fg = getOption("mapsf.fg"),
-#'        leg_bg = getOption("mapsf.bg"), leg_size = 1, add = TRUE)
+#'        leg_val_cex = 0.6, leg_no_data = "No data",
+#'        leg_frame = FALSE, leg_frame_border = getOption("mapsf.foreground"),
+#'        leg_adj = c(0, 0), leg_fg = getOption("mapsf.foreground"),
+#'        leg_bg = getOption("mapsf.background"), leg_size = 1, add = TRUE)
 #'        }
 #'
 #' **grad**: displays graduated symbols. Sizes classes are set with
 #' `breaks` and `nbreaks`. Symbol sizes are set with `cex`.
 #' \preformatted{
-#' mf_map(x, var, type = "grad", breaks = "quantile", nbreaks = 3, col = "tomato4",
-#'        alpha = NULL, border = getOption("mapsf.fg"), pch = 21, cex, lwd,
+#' mf_map(x, var, type = "grad", breaks = "quantile", nbreaks = 3,
+#'        col = "tomato4", alpha = NULL, border = getOption("mapsf.foreground"),
+#'        pch = 21, cex, lwd,
 #'        leg_pos = mf_get_leg_pos(x), leg_title = var, leg_title_cex = 0.8,
-#'        leg_val_cex = 0.6, leg_val_rnd = 2, leg_frame = FALSE,
+#'        leg_val_cex = 0.6, leg_val_rnd = 2, leg_val_dec = ".",
+#'        leg_val_big = "", leg_frame = FALSE,
 #'        leg_adj = c(0, 0), leg_size = 1, leg_border = border,
-#'        leg_box_cex = c(1, 1), leg_fg = getOption("mapsf.fg"),
-#'        leg_bg = getOption("mapsf.bg"), leg_frame_border = getOption("mapsf.fg"),
-#'        add = TRUE)
+#'        leg_box_cex = c(1, 1), leg_fg = getOption("mapsf.foreground"),
+#'        leg_bg = getOption("mapsf.background"),
+#'        leg_frame_border = getOption("mapsf.foreground"), add = TRUE)
 #'        }
 #'
 #' **prop_choro**: displays symbols with sizes proportional to values of a
@@ -111,14 +117,16 @@
 #' \preformatted{
 #' mf_map(x, var, type = "prop_choro", inches = 0.3, val_max, symbol = "circle",
 #'        pal = "Mint", alpha = NULL, rev = FALSE, breaks = "quantile", nbreaks,
-#'        border = getOption("mapsf.fg"), lwd = 0.7, col_na = "white",
+#'        border = getOption("mapsf.foreground"), lwd = 0.7, col_na = "white",
 #'        leg_pos = mf_get_leg_pos(x, 1), leg_title = var,
 #'        leg_title_cex = c(0.8, 0.8), leg_val_cex = c(0.6, 0.6),
-#'        leg_val_rnd = c(0, 2), leg_no_data = "No data",
-#'        leg_frame = c(FALSE, FALSE), leg_frame_border = getOption("mapsf.fg"),
+#'        leg_val_rnd = c(0, 2), leg_val_dec = ".", leg_val_big = "",
+#'        leg_no_data = "No data", leg_frame = c(FALSE, FALSE),
+#'        leg_frame_border = getOption("mapsf.foreground"),
 #'        leg_horiz = c(FALSE, FALSE), leg_adj = c(0, 0),
-#'        leg_fg = getOption("mapsf.fg"), leg_bg = getOption("mapsf.bg"),
-#'        leg_size = 1, leg_box_border = getOption("mapsf.fg"),
+#'        leg_fg = getOption("mapsf.foreground"),
+#'        leg_bg = getOption("mapsf.background"), leg_size = 1,
+#'        leg_box_border = getOption("mapsf.foreground"),
 #'        leg_box_cex = c(1, 1), add = TRUE)
 #'        }
 #'
@@ -128,15 +136,16 @@
 #' \preformatted{
 #' mf_map(x, var, type = "prop_typo", inches = 0.3, val_max, symbol = "circle",
 #'        pal = "Dynamic", alpha = NULL, rev = FALSE, val_order,
-#'        border = getOption("mapsf.fg"), lwd = 0.7, lwd_max = 15,
+#'        border = getOption("mapsf.foreground"), lwd = 0.7, lwd_max = 15,
 #'        col_na = "white",
 #'        leg_pos = mf_get_leg_pos(x, 1), leg_title = var,
 #'        leg_title_cex = c(0.8, 0.8), leg_val_cex = c(0.6, 0.6),
-#'        leg_val_rnd = c(0), leg_no_data = "No data", leg_frame = c(FALSE, FALSE),
-#'        leg_frame_border = getOption("mapsf.fg"), leg_horiz = FALSE,
-#'        leg_adj = c(0, 0), leg_fg = getOption("mapsf.fg"),
-#'        leg_bg = getOption("mapsf.bg"), leg_size = 1,
-#'        leg_box_border = getOption("mapsf.fg"), leg_box_cex = c(1, 1),
+#'        leg_val_rnd = c(0), leg_val_dec = ".", leg_val_big = "",
+#'        leg_no_data = "No data", leg_frame = c(FALSE, FALSE),
+#'        leg_frame_border = getOption("mapsf.foreground"), leg_horiz = FALSE,
+#'        leg_adj = c(0, 0), leg_fg = getOption("mapsf.foreground"),
+#'        leg_bg = getOption("mapsf.background"), leg_size = 1,
+#'        leg_box_border = getOption("mapsf.foreground"), leg_box_cex = c(1, 1),
 #'        add = TRUE)
 #'        }
 #'
@@ -145,16 +154,17 @@
 #' quantitative variable.
 #' \preformatted{
 #' mf_map(x, var, type = "symb_choro", pal = "Mint", alpha = NULL, rev = FALSE,
-#'        breaks = "quantile", nbreaks, border = getOption("mapsf.fg"),
+#'        breaks = "quantile", nbreaks, border = getOption("mapsf.foreground"),
 #'        pch, cex = 2, lwd = 0.7, pch_na = 4, cex_na = 1, col_na = "white",
 #'        val_order,
 #'        leg_pos = mf_get_leg_pos(x, 1), leg_title = var,
 #'        leg_title_cex = c(0.8, 0.8), leg_val_cex = c(0.6, 0.6),
-#'        leg_val_rnd = 2, leg_no_data = c("No data", "No data"),
-#'        leg_frame = c(FALSE, FALSE), leg_frame_border = getOption("mapsf.fg"),
-#'        leg_horiz = FALSE, leg_adj = c(0, 0), leg_fg = getOption("mapsf.fg"),
-#'        leg_bg = getOption("mapsf.bg"), leg_size = 1,
-#'        leg_box_border = getOption("mapsf.fg"), leg_box_cex = c(1, 1),
+#'        leg_val_rnd = 2, leg_val_dec = ".", leg_val_big = "",
+#'        leg_no_data = c("No data", "No data"),
+#'        leg_frame = c(FALSE, FALSE), leg_frame_border = getOption("mapsf.foreground"),
+#'        leg_horiz = FALSE, leg_adj = c(0, 0), leg_fg = getOption("mapsf.foreground"),
+#'        leg_bg = getOption("mapsf.background"), leg_size = 1,
+#'        leg_box_border = getOption("mapsf.foreground"), leg_box_cex = c(1, 1),
 #'        add = TRUE)
 #'        }
 #'
@@ -184,6 +194,8 @@
 #' 'leg_title_cex',
 #' 'leg_val_cex',
 #' 'leg_val_rnd',
+#' 'leg_val_dec',
+#' 'leg_val_big',
 #' 'leg_no_data',
 #' 'leg_frame',
 #' 'add',
@@ -393,6 +405,8 @@ mf_map <- function(x,
                    leg_title_cex,
                    leg_val_cex,
                    leg_val_rnd,
+                   leg_val_dec,
+                   leg_val_big,
                    leg_no_data,
                    leg_frame,
                    leg_frame_border,
