@@ -17,6 +17,8 @@
 #' 'leg_title_cex',
 #' 'leg_val_cex',
 #' 'leg_val_rnd',
+#' 'leg_val_dec',
+#' 'leg_val_big',
 #' 'leg_frame',
 #' 'leg_horiz',
 #' 'leg_frame_border',
@@ -57,6 +59,8 @@ mf_prop <- function(x,
                     leg_title_cex = .8,
                     leg_val_cex = .6,
                     leg_val_rnd = 0,
+                    leg_val_dec = ".",
+                    leg_val_big = "",
                     leg_frame = FALSE,
                     leg_frame_border,
                     leg_horiz = FALSE,
@@ -111,6 +115,8 @@ mf_prop <- function(x,
       title_cex = leg_title_cex,
       val_cex = leg_val_cex,
       val_rnd = leg_val_rnd,
+      val_dec = leg_val_dec,
+      val_big = leg_val_big,
       frame = leg_frame,
       bg = leg_bg,
       fg = leg_fg,
@@ -187,6 +193,8 @@ mf_prop <- function(x,
     title_cex = leg_title_cex,
     val_cex = leg_val_cex,
     val_rnd = leg_val_rnd,
+    val_dec = leg_val_dec,
+    val_big = leg_val_big,
     horiz = leg_horiz,
     frame = leg_frame,
     border = border,
