@@ -21,6 +21,8 @@
 #' 'leg_title_cex',
 #' 'leg_val_cex',
 #' 'leg_val_rnd',
+#' 'leg_val_dec',
+#' 'leg_val_big',
 #' 'leg_no_data',
 #' 'leg_frame',
 #' 'leg_frame_border',
@@ -80,6 +82,8 @@ mf_prop_choro <- function(x,
                           leg_title_cex = c(.8, .8),
                           leg_val_cex = c(.6, .6),
                           leg_val_rnd = c(0, 2),
+                          leg_val_dec = ".",
+                          leg_val_big = "",
                           leg_no_data = "No data",
                           leg_frame = c(FALSE, FALSE),
                           leg_frame_border,
@@ -192,6 +196,8 @@ mf_prop_choro <- function(x,
       inches = size_max,
       col = ccol,
       val_rnd = leg_val_rnd[1],
+      val_dec = leg_val_dec,
+      val_big = leg_val_big,
       border = border,
       lwd = lwd,
       horiz = leg_horiz[1],
@@ -204,6 +210,8 @@ mf_prop_choro <- function(x,
       val = breaks,
       title = leg_title[2],
       val_rnd = leg_val_rnd[2],
+      val_dec = leg_val_dec,
+      val_big = leg_val_big,
       col_na = col_na,
       no_data = no_data,
       no_data_txt = leg_no_data,
@@ -225,7 +233,8 @@ mf_prop_choro <- function(x,
       pos = leg_pos[[1]], val = val, title = leg_title[1],
       symbol = symbol, inches = size_max, col = ccol,
       title_cex = leg_title_cex[1], val_cex = leg_val_cex[1],
-      val_rnd = leg_val_rnd[1],
+      val_rnd = leg_val_rnd[1], val_dec = leg_val_dec,
+      val_big = leg_val_big,
       horiz = leg_horiz[1],
       frame = leg_frame[1], border = border, lwd = lwd,
       bg = leg_bg, fg = leg_fg, self_adjust = TRUE,
@@ -235,7 +244,8 @@ mf_prop_choro <- function(x,
       type = "choro",
       pos = leg_pos[[2]], val = breaks, title = leg_title[2],
       title_cex = leg_title_cex[2], val_cex = leg_val_cex[2],
-      val_rnd = leg_val_rnd[2], horiz = leg_horiz[2],
+      val_rnd = leg_val_rnd[2], val_dec = leg_val_dec,
+      val_big = leg_val_big, horiz = leg_horiz[2],
       col_na = col_na, no_data = no_data, no_data_txt = leg_no_data,
       frame = leg_frame[2], pal = pal, bg = leg_bg, fg = leg_fg,
       size = leg_size, box_border = leg_box_border, box_cex = leg_box_cex
