@@ -77,6 +77,8 @@ mf_raster_interval <- function(ops, ops_leg, pal, breaks, nbreaks, alpha,
     title_cex = ops_leg$leg_title_cex,
     val_cex = ops_leg$leg_val_cex,
     val_rnd = ops_leg$leg_val_rnd,
+    val_dec = ops_leg$leg_val_dec,
+    val_big = ops_leg$leg_val_big,
     frame = ops_leg$leg_frame,
     bg = ops_leg$leg_bg,
     fg = ops_leg$leg_fg,
@@ -167,6 +169,8 @@ mf_raster_continuous <- function(ops, ops_leg, breaks, pal, expandBB, add,
     title_cex = ops_leg$leg_title_cex,
     val_cex = ops_leg$leg_val_cex,
     val_rnd = ops_leg$leg_val_rnd,
+    val_dec = ops_leg$leg_val_dec,
+    val_big = ops_leg$leg_val_big,
     frame = ops_leg$leg_frame,
     bg = ops_leg$leg_bg,
     fg = ops_leg$leg_fg,
