@@ -13,13 +13,17 @@
 #' mf_shadow(mtq)
 #' mf_map(mtq, add = TRUE)
 mf_shadow <- function(x, col, cex = 1, add = FALSE) {
+  op <- par(mar = getOption("mapsf.mar"), no.readonly = TRUE)
+  on.exit(par(op))
   if (add == FALSE) {
     mf_init(x)
   }
   col <- go(col, "highlight", "grey50")
-  d <- cex * strwidth("M", units = "user", cex = 1) / 3
-  z <- st_geometry(x) + c(d, -d)
-
+  xyi <- xyinch(1)
+  ratio <- xyi[2] / xyi[1]
+  d_x <- cex * strwidth("M", units = "user", cex = 1) / 3
+  d_y <- d_x * ratio
+  z <- st_geometry(x) + c(d_x, -d_y)
   mf_map(
     x = z, type = "base", col = col,
     border = col, lwd = .5, add = TRUE
