@@ -19,7 +19,6 @@
 #' 'leg_title',
 #' 'leg_title_cex',
 #' 'leg_val_cex',
-#' 'leg_val_rnd',
 #' 'leg_no_data',
 #' 'leg_frame_border',
 #' 'leg_fg',
@@ -61,7 +60,6 @@ mf_symb <- function(x, var,
                     leg_title = var,
                     leg_title_cex = .8,
                     leg_val_cex = .6,
-                    leg_val_rnd = 2,
                     leg_no_data = "No data",
                     leg_frame = FALSE,
                     leg_frame_border,
